proto

package
v0.0.0-...-4530040 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	URLShortener_Shorten_FullMethodName        = "/shortugo.URLShortener/Shorten"
	URLShortener_ShortenJSON_FullMethodName    = "/shortugo.URLShortener/ShortenJSON"
	URLShortener_ShortenBatch_FullMethodName   = "/shortugo.URLShortener/ShortenBatch"
	URLShortener_Expand_FullMethodName         = "/shortugo.URLShortener/Expand"
	URLShortener_ListUserURLs_FullMethodName   = "/shortugo.URLShortener/ListUserURLs"
	URLShortener_DeleteUserURLs_FullMethodName = "/shortugo.URLShortener/DeleteUserURLs"
	URLShortener_HealthCheck_FullMethodName    = "/shortugo.URLShortener/HealthCheck"
	URLShortener_Ping_FullMethodName           = "/shortugo.URLShortener/Ping"
	URLShortener_Stats_FullMethodName          = "/shortugo.URLShortener/Stats"
)

Variables

var File_proto_shortugo_proto protoreflect.FileDescriptor
var URLShortener_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "shortugo.URLShortener",
	HandlerType: (*URLShortenerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Shorten",
			Handler:    _URLShortener_Shorten_Handler,
		},
		{
			MethodName: "ShortenJSON",
			Handler:    _URLShortener_ShortenJSON_Handler,
		},
		{
			MethodName: "ShortenBatch",
			Handler:    _URLShortener_ShortenBatch_Handler,
		},
		{
			MethodName: "Expand",
			Handler:    _URLShortener_Expand_Handler,
		},
		{
			MethodName: "ListUserURLs",
			Handler:    _URLShortener_ListUserURLs_Handler,
		},
		{
			MethodName: "DeleteUserURLs",
			Handler:    _URLShortener_DeleteUserURLs_Handler,
		},
		{
			MethodName: "HealthCheck",
			Handler:    _URLShortener_HealthCheck_Handler,
		},
		{
			MethodName: "Ping",
			Handler:    _URLShortener_Ping_Handler,
		},
		{
			MethodName: "Stats",
			Handler:    _URLShortener_Stats_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/shortugo.proto",
}

URLShortener_ServiceDesc is the grpc.ServiceDesc for URLShortener service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterURLShortenerServer

func RegisterURLShortenerServer(s grpc.ServiceRegistrar, srv URLShortenerServer)

Types

type DeleteUserURLsRequest

type DeleteUserURLsRequest struct {
	UserId      *string  `protobuf:"bytes,1,opt,name=user_id,json=userId" json:"user_id,omitempty"`
	ShortUrlIds []string `protobuf:"bytes,2,rep,name=short_url_ids,json=shortUrlIds" json:"short_url_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteUserURLsRequest) ClearUserId

func (x *DeleteUserURLsRequest) ClearUserId()

func (*DeleteUserURLsRequest) GetShortUrlIds

func (x *DeleteUserURLsRequest) GetShortUrlIds() []string

func (*DeleteUserURLsRequest) GetUserId

func (x *DeleteUserURLsRequest) GetUserId() string

func (*DeleteUserURLsRequest) HasUserId

func (x *DeleteUserURLsRequest) HasUserId() bool

func (*DeleteUserURLsRequest) ProtoMessage

func (*DeleteUserURLsRequest) ProtoMessage()

func (*DeleteUserURLsRequest) ProtoReflect

func (x *DeleteUserURLsRequest) ProtoReflect() protoreflect.Message

func (*DeleteUserURLsRequest) Reset

func (x *DeleteUserURLsRequest) Reset()

func (*DeleteUserURLsRequest) SetShortUrlIds

func (x *DeleteUserURLsRequest) SetShortUrlIds(v []string)

func (*DeleteUserURLsRequest) SetUserId

func (x *DeleteUserURLsRequest) SetUserId(v string)

func (*DeleteUserURLsRequest) String

func (x *DeleteUserURLsRequest) String() string

type DeleteUserURLsRequest_builder

type DeleteUserURLsRequest_builder struct {
	UserId      *string
	ShortUrlIds []string
	// contains filtered or unexported fields
}

func (DeleteUserURLsRequest_builder) Build

type DeleteUserURLsResponse

type DeleteUserURLsResponse struct {
	Success *bool `protobuf:"varint,1,opt,name=success" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteUserURLsResponse) ClearSuccess

func (x *DeleteUserURLsResponse) ClearSuccess()

func (*DeleteUserURLsResponse) GetSuccess

func (x *DeleteUserURLsResponse) GetSuccess() bool

func (*DeleteUserURLsResponse) HasSuccess

func (x *DeleteUserURLsResponse) HasSuccess() bool

func (*DeleteUserURLsResponse) ProtoMessage

func (*DeleteUserURLsResponse) ProtoMessage()

func (*DeleteUserURLsResponse) ProtoReflect

func (x *DeleteUserURLsResponse) ProtoReflect() protoreflect.Message

func (*DeleteUserURLsResponse) Reset

func (x *DeleteUserURLsResponse) Reset()

func (*DeleteUserURLsResponse) SetSuccess

func (x *DeleteUserURLsResponse) SetSuccess(v bool)

func (*DeleteUserURLsResponse) String

func (x *DeleteUserURLsResponse) String() string

type DeleteUserURLsResponse_builder

type DeleteUserURLsResponse_builder struct {
	Success *bool
	// contains filtered or unexported fields
}

func (DeleteUserURLsResponse_builder) Build

type ExpandRequest

type ExpandRequest struct {
	ShortUrlId *string `protobuf:"bytes,1,opt,name=short_url_id,json=shortUrlId" json:"short_url_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ExpandRequest) ClearShortUrlId

func (x *ExpandRequest) ClearShortUrlId()

func (*ExpandRequest) GetShortUrlId

func (x *ExpandRequest) GetShortUrlId() string

func (*ExpandRequest) HasShortUrlId

func (x *ExpandRequest) HasShortUrlId() bool

func (*ExpandRequest) ProtoMessage

func (*ExpandRequest) ProtoMessage()

func (*ExpandRequest) ProtoReflect

func (x *ExpandRequest) ProtoReflect() protoreflect.Message

func (*ExpandRequest) Reset

func (x *ExpandRequest) Reset()

func (*ExpandRequest) SetShortUrlId

func (x *ExpandRequest) SetShortUrlId(v string)

func (*ExpandRequest) String

func (x *ExpandRequest) String() string

type ExpandRequest_builder

type ExpandRequest_builder struct {
	ShortUrlId *string
	// contains filtered or unexported fields
}

func (ExpandRequest_builder) Build

type ExpandResponse

type ExpandResponse struct {
	OriginalUrl *string `protobuf:"bytes,1,opt,name=original_url,json=originalUrl" json:"original_url,omitempty"`
	// contains filtered or unexported fields
}

func (*ExpandResponse) ClearOriginalUrl

func (x *ExpandResponse) ClearOriginalUrl()

func (*ExpandResponse) GetOriginalUrl

func (x *ExpandResponse) GetOriginalUrl() string

func (*ExpandResponse) HasOriginalUrl

func (x *ExpandResponse) HasOriginalUrl() bool

func (*ExpandResponse) ProtoMessage

func (*ExpandResponse) ProtoMessage()

func (*ExpandResponse) ProtoReflect

func (x *ExpandResponse) ProtoReflect() protoreflect.Message

func (*ExpandResponse) Reset

func (x *ExpandResponse) Reset()

func (*ExpandResponse) SetOriginalUrl

func (x *ExpandResponse) SetOriginalUrl(v string)

func (*ExpandResponse) String

func (x *ExpandResponse) String() string

type ExpandResponse_builder

type ExpandResponse_builder struct {
	OriginalUrl *string
	// contains filtered or unexported fields
}

func (ExpandResponse_builder) Build

type HealthCheckRequest

type HealthCheckRequest struct {
	// contains filtered or unexported fields
}

func (*HealthCheckRequest) ProtoMessage

func (*HealthCheckRequest) ProtoMessage()

func (*HealthCheckRequest) ProtoReflect

func (x *HealthCheckRequest) ProtoReflect() protoreflect.Message

func (*HealthCheckRequest) Reset

func (x *HealthCheckRequest) Reset()

func (*HealthCheckRequest) String

func (x *HealthCheckRequest) String() string

type HealthCheckRequest_builder

type HealthCheckRequest_builder struct {
	// contains filtered or unexported fields
}

func (HealthCheckRequest_builder) Build

type HealthCheckResponse

type HealthCheckResponse struct {
	Status *string `protobuf:"bytes,1,opt,name=status" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*HealthCheckResponse) ClearStatus

func (x *HealthCheckResponse) ClearStatus()

func (*HealthCheckResponse) GetStatus

func (x *HealthCheckResponse) GetStatus() string

func (*HealthCheckResponse) HasStatus

func (x *HealthCheckResponse) HasStatus() bool

func (*HealthCheckResponse) ProtoMessage

func (*HealthCheckResponse) ProtoMessage()

func (*HealthCheckResponse) ProtoReflect

func (x *HealthCheckResponse) ProtoReflect() protoreflect.Message

func (*HealthCheckResponse) Reset

func (x *HealthCheckResponse) Reset()

func (*HealthCheckResponse) SetStatus

func (x *HealthCheckResponse) SetStatus(v string)

func (*HealthCheckResponse) String

func (x *HealthCheckResponse) String() string

type HealthCheckResponse_builder

type HealthCheckResponse_builder struct {
	Status *string
	// contains filtered or unexported fields
}

func (HealthCheckResponse_builder) Build

type ListUserURLsRequest

type ListUserURLsRequest struct {
	UserId *string `protobuf:"bytes,1,opt,name=user_id,json=userId" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ListUserURLsRequest) ClearUserId

func (x *ListUserURLsRequest) ClearUserId()

func (*ListUserURLsRequest) GetUserId

func (x *ListUserURLsRequest) GetUserId() string

func (*ListUserURLsRequest) HasUserId

func (x *ListUserURLsRequest) HasUserId() bool

func (*ListUserURLsRequest) ProtoMessage

func (*ListUserURLsRequest) ProtoMessage()

func (*ListUserURLsRequest) ProtoReflect

func (x *ListUserURLsRequest) ProtoReflect() protoreflect.Message

func (*ListUserURLsRequest) Reset

func (x *ListUserURLsRequest) Reset()

func (*ListUserURLsRequest) SetUserId

func (x *ListUserURLsRequest) SetUserId(v string)

func (*ListUserURLsRequest) String

func (x *ListUserURLsRequest) String() string

type ListUserURLsRequest_builder

type ListUserURLsRequest_builder struct {
	UserId *string
	// contains filtered or unexported fields
}

func (ListUserURLsRequest_builder) Build

type ListUserURLsResponse

type ListUserURLsResponse struct {
	Urls []*URLPair `protobuf:"bytes,1,rep,name=urls" json:"urls,omitempty"`
	// contains filtered or unexported fields
}

func (*ListUserURLsResponse) GetUrls

func (x *ListUserURLsResponse) GetUrls() []*URLPair

func (*ListUserURLsResponse) ProtoMessage

func (*ListUserURLsResponse) ProtoMessage()

func (*ListUserURLsResponse) ProtoReflect

func (x *ListUserURLsResponse) ProtoReflect() protoreflect.Message

func (*ListUserURLsResponse) Reset

func (x *ListUserURLsResponse) Reset()

func (*ListUserURLsResponse) SetUrls

func (x *ListUserURLsResponse) SetUrls(v []*URLPair)

func (*ListUserURLsResponse) String

func (x *ListUserURLsResponse) String() string

type ListUserURLsResponse_builder

type ListUserURLsResponse_builder struct {
	Urls []*URLPair
	// contains filtered or unexported fields
}

func (ListUserURLsResponse_builder) Build

type PingRequest

type PingRequest struct {
	// contains filtered or unexported fields
}

func (*PingRequest) ProtoMessage

func (*PingRequest) ProtoMessage()

func (*PingRequest) ProtoReflect

func (x *PingRequest) ProtoReflect() protoreflect.Message

func (*PingRequest) Reset

func (x *PingRequest) Reset()

func (*PingRequest) String

func (x *PingRequest) String() string

type PingRequest_builder

type PingRequest_builder struct {
	// contains filtered or unexported fields
}

func (PingRequest_builder) Build

func (b0 PingRequest_builder) Build() *PingRequest

type PingResponse

type PingResponse struct {
	Status *string `protobuf:"bytes,1,opt,name=status" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*PingResponse) ClearStatus

func (x *PingResponse) ClearStatus()

func (*PingResponse) GetStatus

func (x *PingResponse) GetStatus() string

func (*PingResponse) HasStatus

func (x *PingResponse) HasStatus() bool

func (*PingResponse) ProtoMessage

func (*PingResponse) ProtoMessage()

func (*PingResponse) ProtoReflect

func (x *PingResponse) ProtoReflect() protoreflect.Message

func (*PingResponse) Reset

func (x *PingResponse) Reset()

func (*PingResponse) SetStatus

func (x *PingResponse) SetStatus(v string)

func (*PingResponse) String

func (x *PingResponse) String() string

type PingResponse_builder

type PingResponse_builder struct {
	Status *string
	// contains filtered or unexported fields
}

func (PingResponse_builder) Build

func (b0 PingResponse_builder) Build() *PingResponse

type ShortenBatchRequest

type ShortenBatchRequest struct {
	UserId *string    `protobuf:"bytes,1,opt,name=user_id,json=userId" json:"user_id,omitempty"`
	Urls   []*URLPair `protobuf:"bytes,2,rep,name=urls" json:"urls,omitempty"`
	// contains filtered or unexported fields
}

func (*ShortenBatchRequest) ClearUserId

func (x *ShortenBatchRequest) ClearUserId()

func (*ShortenBatchRequest) GetUrls

func (x *ShortenBatchRequest) GetUrls() []*URLPair

func (*ShortenBatchRequest) GetUserId

func (x *ShortenBatchRequest) GetUserId() string

func (*ShortenBatchRequest) HasUserId

func (x *ShortenBatchRequest) HasUserId() bool

func (*ShortenBatchRequest) ProtoMessage

func (*ShortenBatchRequest) ProtoMessage()

func (*ShortenBatchRequest) ProtoReflect

func (x *ShortenBatchRequest) ProtoReflect() protoreflect.Message

func (*ShortenBatchRequest) Reset

func (x *ShortenBatchRequest) Reset()

func (*ShortenBatchRequest) SetUrls

func (x *ShortenBatchRequest) SetUrls(v []*URLPair)

func (*ShortenBatchRequest) SetUserId

func (x *ShortenBatchRequest) SetUserId(v string)

func (*ShortenBatchRequest) String

func (x *ShortenBatchRequest) String() string

type ShortenBatchRequest_builder

type ShortenBatchRequest_builder struct {
	UserId *string
	Urls   []*URLPair
	// contains filtered or unexported fields
}

func (ShortenBatchRequest_builder) Build

type ShortenBatchResponse

type ShortenBatchResponse struct {
	Results []*URLPair `protobuf:"bytes,1,rep,name=results" json:"results,omitempty"`
	// contains filtered or unexported fields
}

func (*ShortenBatchResponse) GetResults

func (x *ShortenBatchResponse) GetResults() []*URLPair

func (*ShortenBatchResponse) ProtoMessage

func (*ShortenBatchResponse) ProtoMessage()

func (*ShortenBatchResponse) ProtoReflect

func (x *ShortenBatchResponse) ProtoReflect() protoreflect.Message

func (*ShortenBatchResponse) Reset

func (x *ShortenBatchResponse) Reset()

func (*ShortenBatchResponse) SetResults

func (x *ShortenBatchResponse) SetResults(v []*URLPair)

func (*ShortenBatchResponse) String

func (x *ShortenBatchResponse) String() string

type ShortenBatchResponse_builder

type ShortenBatchResponse_builder struct {
	Results []*URLPair
	// contains filtered or unexported fields
}

func (ShortenBatchResponse_builder) Build

type ShortenRequest

type ShortenRequest struct {
	OriginalUrl *string `protobuf:"bytes,1,opt,name=original_url,json=originalUrl" json:"original_url,omitempty"`
	UserId      *string `protobuf:"bytes,2,opt,name=user_id,json=userId" json:"user_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ShortenRequest) ClearOriginalUrl

func (x *ShortenRequest) ClearOriginalUrl()

func (*ShortenRequest) ClearUserId

func (x *ShortenRequest) ClearUserId()

func (*ShortenRequest) GetOriginalUrl

func (x *ShortenRequest) GetOriginalUrl() string

func (*ShortenRequest) GetUserId

func (x *ShortenRequest) GetUserId() string

func (*ShortenRequest) HasOriginalUrl

func (x *ShortenRequest) HasOriginalUrl() bool

func (*ShortenRequest) HasUserId

func (x *ShortenRequest) HasUserId() bool

func (*ShortenRequest) ProtoMessage

func (*ShortenRequest) ProtoMessage()

func (*ShortenRequest) ProtoReflect

func (x *ShortenRequest) ProtoReflect() protoreflect.Message

func (*ShortenRequest) Reset

func (x *ShortenRequest) Reset()

func (*ShortenRequest) SetOriginalUrl

func (x *ShortenRequest) SetOriginalUrl(v string)

func (*ShortenRequest) SetUserId

func (x *ShortenRequest) SetUserId(v string)

func (*ShortenRequest) String

func (x *ShortenRequest) String() string

type ShortenRequest_builder

type ShortenRequest_builder struct {
	OriginalUrl *string
	UserId      *string
	// contains filtered or unexported fields
}

func (ShortenRequest_builder) Build

type ShortenResponse

type ShortenResponse struct {
	ShortUrl *string `protobuf:"bytes,1,opt,name=short_url,json=shortUrl" json:"short_url,omitempty"`
	// contains filtered or unexported fields
}

func (*ShortenResponse) ClearShortUrl

func (x *ShortenResponse) ClearShortUrl()

func (*ShortenResponse) GetShortUrl

func (x *ShortenResponse) GetShortUrl() string

func (*ShortenResponse) HasShortUrl

func (x *ShortenResponse) HasShortUrl() bool

func (*ShortenResponse) ProtoMessage

func (*ShortenResponse) ProtoMessage()

func (*ShortenResponse) ProtoReflect

func (x *ShortenResponse) ProtoReflect() protoreflect.Message

func (*ShortenResponse) Reset

func (x *ShortenResponse) Reset()

func (*ShortenResponse) SetShortUrl

func (x *ShortenResponse) SetShortUrl(v string)

func (*ShortenResponse) String

func (x *ShortenResponse) String() string

type ShortenResponse_builder

type ShortenResponse_builder struct {
	ShortUrl *string
	// contains filtered or unexported fields
}

func (ShortenResponse_builder) Build

type StatsRequest

type StatsRequest struct {
	Ip *string `protobuf:"bytes,1,opt,name=ip" json:"ip,omitempty"` // IP address of the client, used for trusted subnet validation
	// contains filtered or unexported fields
}

func (*StatsRequest) ClearIp

func (x *StatsRequest) ClearIp()

func (*StatsRequest) GetIp

func (x *StatsRequest) GetIp() string

func (*StatsRequest) HasIp

func (x *StatsRequest) HasIp() bool

func (*StatsRequest) ProtoMessage

func (*StatsRequest) ProtoMessage()

func (*StatsRequest) ProtoReflect

func (x *StatsRequest) ProtoReflect() protoreflect.Message

func (*StatsRequest) Reset

func (x *StatsRequest) Reset()

func (*StatsRequest) SetIp

func (x *StatsRequest) SetIp(v string)

func (*StatsRequest) String

func (x *StatsRequest) String() string

type StatsRequest_builder

type StatsRequest_builder struct {
	Ip *string
	// contains filtered or unexported fields
}

func (StatsRequest_builder) Build

func (b0 StatsRequest_builder) Build() *StatsRequest

type StatsResponse

type StatsResponse struct {
	UrlCount  *int64 `protobuf:"varint,1,opt,name=url_count,json=urlCount" json:"url_count,omitempty"`
	UserCount *int64 `protobuf:"varint,2,opt,name=user_count,json=userCount" json:"user_count,omitempty"`
	// contains filtered or unexported fields
}

func (*StatsResponse) ClearUrlCount

func (x *StatsResponse) ClearUrlCount()

func (*StatsResponse) ClearUserCount

func (x *StatsResponse) ClearUserCount()

func (*StatsResponse) GetUrlCount

func (x *StatsResponse) GetUrlCount() int64

func (*StatsResponse) GetUserCount

func (x *StatsResponse) GetUserCount() int64

func (*StatsResponse) HasUrlCount

func (x *StatsResponse) HasUrlCount() bool

func (*StatsResponse) HasUserCount

func (x *StatsResponse) HasUserCount() bool

func (*StatsResponse) ProtoMessage

func (*StatsResponse) ProtoMessage()

func (*StatsResponse) ProtoReflect

func (x *StatsResponse) ProtoReflect() protoreflect.Message

func (*StatsResponse) Reset

func (x *StatsResponse) Reset()

func (*StatsResponse) SetUrlCount

func (x *StatsResponse) SetUrlCount(v int64)

func (*StatsResponse) SetUserCount

func (x *StatsResponse) SetUserCount(v int64)

func (*StatsResponse) String

func (x *StatsResponse) String() string

type StatsResponse_builder

type StatsResponse_builder struct {
	UrlCount  *int64
	UserCount *int64
	// contains filtered or unexported fields
}

func (StatsResponse_builder) Build

type URLPair

type URLPair struct {
	CorrelationId *string `protobuf:"bytes,1,opt,name=correlation_id,json=correlationId" json:"correlation_id,omitempty"`
	OriginalUrl   *string `protobuf:"bytes,2,opt,name=original_url,json=originalUrl" json:"original_url,omitempty"`
	ShortUrl      *string `protobuf:"bytes,3,opt,name=short_url,json=shortUrl" json:"short_url,omitempty"`
	// contains filtered or unexported fields
}

func (*URLPair) ClearCorrelationId

func (x *URLPair) ClearCorrelationId()

func (*URLPair) ClearOriginalUrl

func (x *URLPair) ClearOriginalUrl()

func (*URLPair) ClearShortUrl

func (x *URLPair) ClearShortUrl()

func (*URLPair) GetCorrelationId

func (x *URLPair) GetCorrelationId() string

func (*URLPair) GetOriginalUrl

func (x *URLPair) GetOriginalUrl() string

func (*URLPair) GetShortUrl

func (x *URLPair) GetShortUrl() string

func (*URLPair) HasCorrelationId

func (x *URLPair) HasCorrelationId() bool

func (*URLPair) HasOriginalUrl

func (x *URLPair) HasOriginalUrl() bool

func (*URLPair) HasShortUrl

func (x *URLPair) HasShortUrl() bool

func (*URLPair) ProtoMessage

func (*URLPair) ProtoMessage()

func (*URLPair) ProtoReflect

func (x *URLPair) ProtoReflect() protoreflect.Message

func (*URLPair) Reset

func (x *URLPair) Reset()

func (*URLPair) SetCorrelationId

func (x *URLPair) SetCorrelationId(v string)

func (*URLPair) SetOriginalUrl

func (x *URLPair) SetOriginalUrl(v string)

func (*URLPair) SetShortUrl

func (x *URLPair) SetShortUrl(v string)

func (*URLPair) String

func (x *URLPair) String() string

type URLPair_builder

type URLPair_builder struct {
	CorrelationId *string
	OriginalUrl   *string
	ShortUrl      *string
	// contains filtered or unexported fields
}

func (URLPair_builder) Build

func (b0 URLPair_builder) Build() *URLPair

type URLShortenerClient

type URLShortenerClient interface {
	Shorten(ctx context.Context, in *ShortenRequest, opts ...grpc.CallOption) (*ShortenResponse, error)
	ShortenJSON(ctx context.Context, in *ShortenRequest, opts ...grpc.CallOption) (*ShortenResponse, error)
	ShortenBatch(ctx context.Context, in *ShortenBatchRequest, opts ...grpc.CallOption) (*ShortenBatchResponse, error)
	Expand(ctx context.Context, in *ExpandRequest, opts ...grpc.CallOption) (*ExpandResponse, error)
	ListUserURLs(ctx context.Context, in *ListUserURLsRequest, opts ...grpc.CallOption) (*ListUserURLsResponse, error)
	DeleteUserURLs(ctx context.Context, in *DeleteUserURLsRequest, opts ...grpc.CallOption) (*DeleteUserURLsResponse, error)
	HealthCheck(ctx context.Context, in *HealthCheckRequest, opts ...grpc.CallOption) (*HealthCheckResponse, error)
	Ping(ctx context.Context, in *PingRequest, opts ...grpc.CallOption) (*PingResponse, error)
	Stats(ctx context.Context, in *StatsRequest, opts ...grpc.CallOption) (*StatsResponse, error)
}

URLShortenerClient is the client API for URLShortener service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type URLShortenerServer

URLShortenerServer is the server API for URLShortener service. All implementations must embed UnimplementedURLShortenerServer for forward compatibility.

type UnimplementedURLShortenerServer

type UnimplementedURLShortenerServer struct{}

UnimplementedURLShortenerServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedURLShortenerServer) DeleteUserURLs

func (UnimplementedURLShortenerServer) Expand

func (UnimplementedURLShortenerServer) HealthCheck

func (UnimplementedURLShortenerServer) ListUserURLs

func (UnimplementedURLShortenerServer) Ping

func (UnimplementedURLShortenerServer) Shorten

func (UnimplementedURLShortenerServer) ShortenBatch

func (UnimplementedURLShortenerServer) ShortenJSON

func (UnimplementedURLShortenerServer) Stats

type UnsafeURLShortenerServer

type UnsafeURLShortenerServer interface {
	// contains filtered or unexported methods
}

UnsafeURLShortenerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to URLShortenerServer will result in compilation errors.

Jump to